@@ -21,10 +21,10 @@
 #ifndef ALARMCALENDAR_H
 #define ALARMCALENDAR_H
 
-#include "akonadimodel.h"
 #include "eventid.h"
+#include "resources/resource.h"
 
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/KAEvent>
 
 #include <KCalendarCore/FileStorage>
 #include <KCalendarCore/Event>
@@ -33,7 +33,6 @@
 #include <QObject>
 #include <QUrl>
 
-
 using namespace KAlarmCal;
 
 
@@ -97,6 +96,7 @@ class AlarmCalendar : public QObject
     private Q_SLOTS:
         void                  slotResourceSettingsChanged(Resource&, ResourceType::Changes);
         void                  slotResourcesPopulated();
+        void                  slotResourceAdded(Resource&);
         void                  slotEventsAdded(Resource&, const QList<KAEvent>&);
         void                  slotEventsToBeRemoved(Resource&, const QList<KAEvent>&);
         void                  slotEventUpdated(Resource&, const KAEvent&);
@@ -111,10 +111,10 @@ class AlarmCalendar : public QObject
         bool                  saveCal(const QString& newFile = QString());
         bool                  isValid() const   { return mCalType == RESOURCES || mCalendarStorage; }
         void                  addNewEvent(const Resource&, KAEvent*, bool replace = false);
-        CalEvent::Type        deleteEventInternal(const KAEvent&, bool deleteFromAkonadi = true);
-        CalEvent::Type        deleteEventInternal(const KAEvent&, Resource&, bool deleteFromAkonadi = true);
+        CalEvent::Type        deleteEventInternal(const KAEvent&, bool deleteFromResources = true);
+        CalEvent::Type        deleteEventInternal(const KAEvent&, Resource&, bool deleteFromResources = true);
         CalEvent::Type        deleteEventInternal(const QString& eventID, const KAEvent&, Resource&,
-                                                  bool deleteFromAkonadi = true);
+                                                  bool deleteFromResources = true);
         void                  updateDisplayKAEvents();
         void                  removeKAEvents(ResourceId, bool closing = false, CalEvent::Types = CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE);
         void                  findEarliestAlarm(const Resource&);
@@ -126,7 +126,7 @@ class AlarmCalendar : public QObject
         static AlarmCalendar* mDisplayCalendar;    // the display calendar
         static QUrl           mLastImportUrl;      // last URL for Import Alarms file dialogue
 
-        KCalendarCore::FileStorage::Ptr mCalendarStorage; // null pointer for Akonadi
+        KCalendarCore::FileStorage::Ptr mCalendarStorage; // for display calendar; null if resources calendar
         ResourceMap           mResourceMap;
         KAEventMap            mEventMap;           // lookup of all events by UID
         EarliestMap           mEarliestAlarm;      // alarm with earliest trigger time, by resource
@@ -136,11 +136,11 @@ class AlarmCalendar : public QObject
         QString               mLocalFile;          // calendar file, or local copy if it's a remote file
         CalType               mCalType;            // what type of calendar mCalendar is (resources/ical/vcal)
         CalEvent::Type        mEventType;          // what type of events the calendar file is for
-        bool                  mOpen{false};        // true if the calendar file is open
-        bool                  mIgnoreAtLogin{false}; // ignore new/updated repeat-at-login alarms
-        int                   mUpdateCount{0};     // nesting level of group of calendar update calls
-        bool                  mUpdateSave{false};  // save() was called while mUpdateCount > 0
-        bool                  mHaveDisabledAlarms{false}; // there is at least one individually disabled alarm
+        bool                  mOpen {false};       // true if the calendar file is open
+        bool                  mIgnoreAtLogin {false}; // ignore new/updated repeat-at-login alarms
+        int                   mUpdateCount {0};    // nesting level of group of calendar update calls
+        bool                  mUpdateSave {false}; // save() was called while mUpdateCount > 0
+        bool                  mHaveDisabledAlarms {false}; // there is at least one individually disabled alarm
 
         using QObject::event;   // prevent "hidden" warning
 };
