@@ -21,11 +21,11 @@
 #ifndef EDITDLG_H
 #define EDITDLG_H
 
-#include <resources/resource.h>
+#include "resources/resource.h"
 
-#include <kalarmcal/alarmtext.h>
-#include <kalarmcal/datetime.h>
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/AlarmText>
+#include <KAlarmCal/DateTime>
+#include <KAlarmCal/KAEvent>
 
 #include <QDialog>
 #include <QTime>
@@ -155,7 +155,7 @@ class EditAlarmDlg : public QDialog
 
         QDialogButtonBox*   mButtonBox;
         QAbstractButton*    mTryButton;
-        QAbstractButton*    mLoadTemplateButton{nullptr};
+        QAbstractButton*    mLoadTemplateButton {nullptr};
         QAbstractButton*    mMoreLessButton;
 
     private:
@@ -164,27 +164,27 @@ class EditAlarmDlg : public QDialog
         StackedScrollGroup* mTabScrollGroup;
         int                 mMainPageIndex;
         int                 mRecurPageIndex;
-        bool                mMainPageShown{false};           // true once the main tab has been displayed
-        bool                mRecurPageShown{false};          // true once the recurrence tab has been displayed
-        bool                mRecurSetDefaultEndDate{true};   // adjust default end date/time when recurrence tab is displayed
+        bool                mMainPageShown {false};          // true once the main tab has been displayed
+        bool                mRecurPageShown {false};         // true once the recurrence tab has been displayed
+        bool                mRecurSetDefaultEndDate {true};  // adjust default end date/time when recurrence tab is displayed
 
         // Templates
-        QLineEdit*          mTemplateName{nullptr};
+        QLineEdit*          mTemplateName {nullptr};
         ButtonGroup*        mTemplateTimeGroup;
-        RadioButton*        mTemplateDefaultTime; // no alarm time is specified
-        RadioButton*        mTemplateUseTimeAfter;// alarm time is specified as an offset from current
-        RadioButton*        mTemplateAnyTime;     // alarms have date only, no time
-        RadioButton*        mTemplateUseTime;     // an alarm time is specified
-        TimeSpinBox*        mTemplateTimeAfter;   // the specified offset from the current time
-        TimeEdit*           mTemplateTime;        // the alarm time which is specified
-        QGroupBox*          mDeferGroup{nullptr};
+        RadioButton*        mTemplateDefaultTime;  // no alarm time is specified
+        RadioButton*        mTemplateUseTimeAfter; // alarm time is specified as an offset from current
+        RadioButton*        mTemplateAnyTime;      // alarms have date only, no time
+        RadioButton*        mTemplateUseTime;      // an alarm time is specified
+        TimeSpinBox*        mTemplateTimeAfter;    // the specified offset from the current time
+        TimeEdit*           mTemplateTime;         // the alarm time which is specified
+        QGroupBox*          mDeferGroup {nullptr};
         QLabel*             mDeferTimeLabel;
-        QPushButton*        mDeferChangeButton{nullptr};
+        QPushButton*        mDeferChangeButton {nullptr};
 
-        AlarmTimeWidget*    mTimeWidget{nullptr};
+        AlarmTimeWidget*    mTimeWidget {nullptr};
         LateCancelSelector* mLateCancel;
         Reminder*           mReminder;             // null except for display alarms
-        CheckBox*           mShowInKorganizer{nullptr};
+        CheckBox*           mShowInKorganizer {nullptr};
 
         QFrame*             mMoreOptions;          // contains options hidden by default
 
@@ -196,7 +196,7 @@ class EditAlarmDlg : public QDialog
         bool                mUseResourceEventId;   // whether to use mResourceEventId
         QString             mResourceEventId;      // if non-null, save alarm in resource containing this event ID
         Resource            mResource;             // resource to save event into, or invalid
-        int                 mDeferGroupHeight{0};  // height added by deferred time widget
+        int                 mDeferGroupHeight {0}; // height added by deferred time widget
         int                 mDesktop;              // desktop to display the dialog in
         QString             mEventId;              // UID of event being edited, or blank for new event
         bool                mTemplate;             // editing an alarm template
@@ -206,10 +206,10 @@ class EditAlarmDlg : public QDialog
         mutable bool        mOnlyDeferred;         // the only change made in the dialog was to the existing deferral
         bool                mDesiredReadOnly;      // the specified read-only status of the dialog
         bool                mReadOnly;             // the actual read-only status of the dialog
-        bool                mShowingMore{true};    // the More Options button has been clicked
+        bool                mShowingMore {true};   // the More Options button has been clicked
 
         // Initial state of all controls
-        KAEvent*            mSavedEvent{nullptr};
+        KAEvent*            mSavedEvent {nullptr};
         QString             mSavedTemplateName;     // mTemplateName value
         QAbstractButton*    mSavedTemplateTimeType; // selected button in mTemplateTimeGroup
         QTime               mSavedTemplateTime;     // mTemplateTime value
